@@ -3,7 +3,7 @@ import datetime
 import os 
 import pandas as pd
 import csv
-class utility:
+class aws:
 
     def __init__(self):
         print("constructor created")
